@@ -4,13 +4,16 @@
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-# https://www.apache.org/licenses/LICENSE-2.0
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import absolute_import, division, print_function
+from __future__ import unicode_literals
+
 import pretend
 import pytest
 
@@ -29,4 +32,4 @@ def test_dispatch_to_subcommand(monkeypatch):
 
 def test_catches_enoent():
     with pytest.raises(SystemExit):
-        cli.dispatch(["non-existent-command"])
+        cli.dispatch(["non-existant-command"])
