@@ -85,18 +85,8 @@ def test_set_certificate_authority(default_repo):
 
 
 def test_make_user_agent_string(default_repo):
-    """Add twine and its dependencies to User-Agent session header."""
-    assert "User-Agent" in default_repo.session.headers
-
-    user_agent = default_repo.session.headers["User-Agent"]
-    packages = (
-        "twine/",
-        "requests/",
-        "requests-toolbelt/",
-        "pkginfo/",
-        "importlib_metadata/",
-    )
-    assert all(p in user_agent for p in packages)
+    """Add twine to User-Agent session header."""
+    assert "twine/" in default_repo.session.headers["User-Agent"]
 
 
 def response_with(**kwattrs):
@@ -195,18 +185,21 @@ def test_package_is_registered(default_repo):
 
 
 @pytest.mark.parametrize("disable_progress_bar", [True, False])
-def test_disable_progress_bar_is_forwarded_to_tqdm(
+def test_disable_progress_bar_is_forwarded_to_rich(
     monkeypatch, tmpdir, disable_progress_bar, default_repo
 ):
     """Toggle display of upload progress bar."""
 
     @contextmanager
-    def progressbarstub(*args, **kwargs):
+    def ProgressStub(*args, **kwargs):
         assert "disable" in kwargs
         assert kwargs["disable"] == disable_progress_bar
-        yield
+        yield pretend.stub(
+            add_task=lambda description, total: None,
+            update=lambda task_id, completed: None,
+        )
 
-    monkeypatch.setattr(repository, "ProgressBar", progressbarstub)
+    monkeypatch.setattr(repository.rich.progress, "Progress", ProgressStub)
     default_repo.disable_progress_bar = disable_progress_bar
 
     default_repo.session = pretend.stub(
@@ -230,7 +223,7 @@ def test_disable_progress_bar_is_forwarded_to_tqdm(
     default_repo.upload(package)
 
 
-def test_upload_retry(tmpdir, default_repo, capsys):
+def test_upload_retry(tmpdir, default_repo, caplog):
     """Print retry messages when the upload response indicates a server error."""
     default_repo.disable_progress_bar = True
 
@@ -254,33 +247,27 @@ def test_upload_retry(tmpdir, default_repo, capsys):
     # Upload with default max_redirects of 5
     default_repo.upload(package)
 
-    msg = [
+    assert caplog.messages == [
         (
-            "Uploading fake.whl\n"
-            'Received "500: Internal server error" '
-            f"Package upload appears to have failed.  Retry {i} of 5"
+            'Received "500: Internal server error"\n'
+            f"Package upload appears to have failed. Retry {i} of 5."
         )
         for i in range(1, 6)
     ]
 
-    captured = capsys.readouterr()
-    assert captured.out == "\n".join(msg) + "\n"
+    caplog.clear()
 
     # Upload with custom max_redirects of 3
     default_repo.upload(package, 3)
 
-    msg = [
+    assert caplog.messages == [
         (
-            "Uploading fake.whl\n"
-            'Received "500: Internal server error" '
-            f"Package upload appears to have failed.  Retry {i} of 3"
+            'Received "500: Internal server error"\n'
+            f"Package upload appears to have failed. Retry {i} of 3."
         )
         for i in range(1, 4)
     ]
 
-    captured = capsys.readouterr()
-    assert captured.out == "\n".join(msg) + "\n"
-
 
 @pytest.mark.parametrize(
     "package_meta,repository_url,release_urls",
