@@ -1,3 +1,9 @@
+"""Top-level module for Twine.
+
+The contents of this package are not a public API. For more details, see
+https://github.com/pypa/twine/issues/194 and https://github.com/pypa/twine/issues/665.
+"""
+
 # Copyright 2018 Donald Stufft and individual contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -24,13 +30,7 @@ __all__ = (
 
 __copyright__ = "Copyright 2019 Donald Stufft and individual contributors"
 
-import sys
-
-if sys.version_info[:2] >= (3, 8):
-    from importlib import metadata as importlib_metadata
-else:
-    import importlib_metadata
-
+import importlib_metadata
 
 metadata = importlib_metadata.metadata("twine")
 
@@ -41,4 +41,4 @@ __uri__ = metadata["home-page"]
 __version__ = metadata["version"]
 __author__ = metadata["author"]
 __email__ = metadata["author-email"]
-__license__ = metadata["license"]
+__license__ = None
