@@ -1,4 +1,5 @@
 """Module containing the logic for ``twine check``."""
+
 # Copyright 2018 Dustin Ingram
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,18 +14,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import argparse
-import cgi
+import email.message
 import io
+import logging
 import re
-import sys
-import textwrap
-from typing import IO, List, Optional, Tuple, cast
+from typing import Dict, List, Optional, Tuple, cast
 
 import readme_renderer.rst
+from rich import print
 
 from twine import commands
 from twine import package as package_file
 
+logger = logging.getLogger(__name__)
+
+
 _RENDERERS = {
     None: readme_renderer.rst,  # Default if description_content_type is None
     "text/plain": None,  # Rendering cannot fail
@@ -45,27 +49,29 @@ _REPORT_RE = re.compile(
 )
 
 
-class _WarningStream:
-    def __init__(self) -> None:
-        self.output = io.StringIO()
-
-    def write(self, text: str) -> None:
+class _WarningStream(io.StringIO):
+    def write(self, text: str) -> int:
         matched = _REPORT_RE.search(text)
+        if matched:
+            line = matched.group("line")
+            level_text = matched.group("level").capitalize()
+            message = matched.group("message").rstrip("\r\n")
+            text = f"line {line}: {level_text}: {message}\n"
 
-        if not matched:
-            self.output.write(text)
-            return
-
-        self.output.write(
-            "line {line}: {level_text}: {message}\n".format(
-                level_text=matched.group("level").capitalize(),
-                line=matched.group("line"),
-                message=matched.group("message").rstrip("\r\n"),
-            )
-        )
+        return super().write(text)
 
     def __str__(self) -> str:
-        return self.output.getvalue()
+        return self.getvalue().strip()
+
+
+def _parse_content_type(value: str) -> Tuple[str, Dict[str, str]]:
+    """Implement logic of deprecated cgi.parse_header().
+
+    From https://docs.python.org/3.11/library/cgi.html#cgi.parse_header.
+    """
+    msg = email.message.EmailMessage()
+    msg["content-type"] = value
+    return msg.get_content_type(), msg["content-type"].params
 
 
 def _check_file(
@@ -87,10 +93,10 @@ def _check_file(
         )
         description_content_type = "text/x-rst"
 
-    content_type, params = cgi.parse_header(description_content_type)
+    content_type, params = _parse_content_type(description_content_type)
     renderer = _RENDERERS.get(content_type, _RENDERERS[None])
 
-    if description in {None, "UNKNOWN\n\n\n"}:
+    if description is None or description.rstrip() == "UNKNOWN":
         warnings.append("`long_description` missing.")
     elif renderer:
         rendering_result = renderer.render(
@@ -104,7 +110,6 @@ def _check_file(
 
 def check(
     dists: List[str],
-    output_stream: IO[str] = sys.stdout,
     strict: bool = False,
 ) -> bool:
     """Check that a distribution will render correctly on PyPI and display the results.
@@ -124,39 +129,37 @@ def check(
     """
     uploads = [i for i in commands._find_dists(dists) if not i.endswith(".asc")]
     if not uploads:  # Return early, if there are no files to check.
-        output_stream.write("No files to check.\n")
+        logger.error("No files to check.")
         return False
 
     failure = False
 
     for filename in uploads:
-        output_stream.write("Checking %s: " % filename)
+        print(f"Checking {filename}: ", end="")
         render_warning_stream = _WarningStream()
         warnings, is_ok = _check_file(filename, render_warning_stream)
 
         # Print the status and/or error
         if not is_ok:
             failure = True
-            output_stream.write("FAILED\n")
-
-            error_text = (
-                "`long_description` has syntax errors in markup and "
-                "would not be rendered on PyPI.\n"
+            print("[red]FAILED[/red]")
+            logger.error(
+                "`long_description` has syntax errors in markup"
+                " and would not be rendered on PyPI."
+                f"\n{render_warning_stream}"
             )
-            output_stream.write(textwrap.indent(error_text, "  "))
-            output_stream.write(textwrap.indent(str(render_warning_stream), "    "))
         elif warnings:
             if strict:
                 failure = True
-                output_stream.write("FAILED, due to warnings\n")
+                print("[red]FAILED due to warnings[/red]")
             else:
-                output_stream.write("PASSED, with warnings\n")
+                print("[yellow]PASSED with warnings[/yellow]")
         else:
-            output_stream.write("PASSED\n")
+            print("[green]PASSED[/green]")
 
         # Print warnings after the status and/or error
         for message in warnings:
-            output_stream.write("  warning: " + message + "\n")
+            logger.warning(message)
 
     return failure
 
