@@ -1,4 +1,5 @@
 """Module containing logic for handling settings."""
+
 # Copyright 2018 Ian Stapleton Cordasco
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -12,14 +13,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import cast, Optional
-
 import argparse
+import contextlib
+import logging
+from typing import Any, Optional, cast
 
+from twine import auth
 from twine import exceptions
 from twine import repository
 from twine import utils
-from twine import auth
 
 
 class Settings:
@@ -44,78 +46,64 @@ class Settings:
         self,
         *,
         sign: bool = False,
-        sign_with: Optional[str] = 'gpg',
+        sign_with: str = "gpg",
         identity: Optional[str] = None,
         username: Optional[str] = None,
         password: Optional[str] = None,
         non_interactive: bool = False,
         comment: Optional[str] = None,
-        config_file: str = '~/.pypirc',
+        config_file: str = utils.DEFAULT_CONFIG_FILE,
         skip_existing: bool = False,
         cacert: Optional[str] = None,
         client_cert: Optional[str] = None,
-        repository_name: str = 'pypi',
+        repository_name: str = "pypi",
         repository_url: Optional[str] = None,
         verbose: bool = False,
         disable_progress_bar: bool = False,
-        **ignored_kwargs
+        **ignored_kwargs: Any,
     ) -> None:
         """Initialize our settings instance.
 
-        :param bool sign:
+        :param sign:
             Configure whether the package file should be signed.
-
-            This defaults to ``False``.
-        :param str sign_with:
+        :param sign_with:
             The name of the executable used to sign the package with.
-
-            This defaults to ``gpg``.
-        :param str identity:
+        :param identity:
             The GPG identity that should be used to sign the package file.
-        :param str username:
+        :param username:
             The username used to authenticate to the repository (package
             index).
-        :param str password:
+        :param password:
             The password used to authenticate to the repository (package
             index).
-        :param bool non_interactive:
+        :param non_interactive:
             Do not interactively prompt for username/password if the required
             credentials are missing.
-
-            This defaults to ``False``.
-        :param str comment:
+        :param comment:
             The comment to include with each distribution file.
-        :param str config_file:
+        :param config_file:
             The path to the configuration file to use.
-
-            This defaults to ``~/.pypirc``.
-        :param bool skip_existing:
+        :param skip_existing:
             Specify whether twine should continue uploading files if one
             of them already exists. This primarily supports PyPI. Other
             package indexes may not be supported.
-
-            This defaults to ``False``.
-        :param str cacert:
+        :param cacert:
             The path to the bundle of certificates used to verify the TLS
             connection to the package index.
-        :param str client_cert:
-            The path to the client certificate used to perform authentication
-            to the index.
-
-            This must be a single file that contains both the private key and
+        :param client_cert:
+            The path to the client certificate used to perform authentication to the
+            index. This must be a single file that contains both the private key and
             the PEM-encoded certificate.
-        :param str repository_name:
+        :param repository_name:
             The name of the repository (package index) to interact with. This
             should correspond to a section in the config file.
-        :param str repository_url:
+        :param repository_url:
             The URL of the repository (package index) to interact with. This
             will override the settings inferred from ``repository_name``.
-        :param bool verbose:
+        :param verbose:
             Show verbose output.
-        :param bool disable_progress_bar:
+        :param disable_progress_bar:
             Disable the progress bar.
-
-            This defaults to ``False``
         """
         self.config_file = config_file
         self.comment = comment
@@ -123,10 +111,13 @@ class Settings:
         self.disable_progress_bar = disable_progress_bar
         self.skip_existing = skip_existing
         self._handle_repository_options(
-            repository_name=repository_name, repository_url=repository_url,
+            repository_name=repository_name,
+            repository_url=repository_url,
         )
         self._handle_package_signing(
-            sign=sign, sign_with=sign_with, identity=identity,
+            sign=sign,
+            sign_with=sign_with,
+            identity=identity,
         )
         # _handle_certificates relies on the parsed repository config
         self._handle_certificates(cacert, client_cert)
@@ -136,25 +127,43 @@ class Settings:
         )
 
     @property
-    def username(self):
+    def username(self) -> Optional[str]:
         return self.auth.username
 
     @property
-    def password(self):
-        return None if self.client_cert else self.auth.password
+    def password(self) -> Optional[str]:
+        with self._allow_noninteractive():
+            return self.auth.password
+
+    def _allow_noninteractive(self) -> "contextlib.AbstractContextManager[None]":
+        """Bypass NonInteractive error when client cert is present."""
+        suppressed = (exceptions.NonInteractive,) if self.client_cert else ()
+        return contextlib.suppress(*suppressed)
+
+    @property
+    def verbose(self) -> bool:
+        return self._verbose
+
+    @verbose.setter
+    def verbose(self, verbose: bool) -> None:
+        """Initialize a logger based on the --verbose option."""
+        self._verbose = verbose
+        twine_logger = logging.getLogger("twine")
+        twine_logger.setLevel(logging.INFO if verbose else logging.WARNING)
 
     @staticmethod
     def register_argparse_arguments(parser: argparse.ArgumentParser) -> None:
         """Register the arguments for argparse."""
         parser.add_argument(
-            "-r", "--repository",
+            "-r",
+            "--repository",
             action=utils.EnvironmentDefault,
             env="TWINE_REPOSITORY",
             default="pypi",
             help="The repository (package index) to upload the package to. "
-                 "Should be a section in the config file (default: "
-                 "%(default)s). (Can also be set via %(env)s environment "
-                 "variable.)",
+            "Should be a section in the config file (default: "
+            "%(default)s). (Can also be set via %(env)s environment "
+            "variable.)",
         )
         parser.add_argument(
             "--repository-url",
@@ -163,11 +172,12 @@ class Settings:
             default=None,
             required=False,
             help="The repository (package index) URL to upload the package to."
-                 " This overrides --repository. "
-                 "(Can also be set via %(env)s environment variable.)"
+            " This overrides --repository. "
+            "(Can also be set via %(env)s environment variable.)",
         )
         parser.add_argument(
-            "-s", "--sign",
+            "-s",
+            "--sign",
             action="store_true",
             default=False,
             help="Sign files to upload using GPG.",
@@ -178,42 +188,46 @@ class Settings:
             help="GPG program used to sign uploads (default: %(default)s).",
         )
         parser.add_argument(
-            "-i", "--identity",
+            "-i",
+            "--identity",
             help="GPG identity used to sign files.",
         )
         parser.add_argument(
-            "-u", "--username",
+            "-u",
+            "--username",
             action=utils.EnvironmentDefault,
             env="TWINE_USERNAME",
             required=False,
             help="The username to authenticate to the repository "
-                 "(package index) as. (Can also be set via "
-                 "%(env)s environment variable.)",
+            "(package index) as. (Can also be set via "
+            "%(env)s environment variable.)",
         )
         parser.add_argument(
-            "-p", "--password",
+            "-p",
+            "--password",
             action=utils.EnvironmentDefault,
             env="TWINE_PASSWORD",
             required=False,
             help="The password to authenticate to the repository "
-                 "(package index) with. (Can also be set via "
-                 "%(env)s environment variable.)",
+            "(package index) with. (Can also be set via "
+            "%(env)s environment variable.)",
         )
         parser.add_argument(
             "--non-interactive",
             action=utils.EnvironmentFlag,
             env="TWINE_NON_INTERACTIVE",
             help="Do not interactively prompt for username/password if the "
-                 "required credentials are missing. (Can also be set via "
-                 "%(env)s environment variable.)"
+            "required credentials are missing. (Can also be set via "
+            "%(env)s environment variable.)",
         )
         parser.add_argument(
-            "-c", "--comment",
+            "-c",
+            "--comment",
             help="The comment to include with the distribution file.",
         )
         parser.add_argument(
             "--config-file",
-            default="~/.pypirc",
+            default=utils.DEFAULT_CONFIG_FILE,
             help="The .pypirc config file to use.",
         )
         parser.add_argument(
@@ -221,8 +235,8 @@ class Settings:
             default=False,
             action="store_true",
             help="Continue uploading files if one already exists. (Only valid "
-                 "when uploading to PyPI. Other implementations may not "
-                 "support this.)",
+            "when uploading to PyPI. Other implementations may not "
+            "support this.)",
         )
         parser.add_argument(
             "--cert",
@@ -232,42 +246,39 @@ class Settings:
             required=False,
             metavar="path",
             help="Path to alternate CA bundle (can also be set via %(env)s "
-                 "environment variable).",
+            "environment variable).",
         )
         parser.add_argument(
             "--client-cert",
             metavar="path",
             help="Path to SSL client certificate, a single file containing the"
-                 " private key and the certificate in PEM format.",
+            " private key and the certificate in PEM format.",
         )
         parser.add_argument(
             "--verbose",
             default=False,
             required=False,
             action="store_true",
-            help="Show verbose output."
+            help="Show verbose output.",
         )
         parser.add_argument(
             "--disable-progress-bar",
             default=False,
             required=False,
             action="store_true",
-            help="Disable the progress bar."
+            help="Disable the progress bar.",
         )
 
     @classmethod
     def from_argparse(cls, args: argparse.Namespace) -> "Settings":
         """Generate the Settings from parsed arguments."""
         settings = vars(args)
-        settings['repository_name'] = settings.pop('repository')
-        settings['cacert'] = settings.pop('cert')
+        settings["repository_name"] = settings.pop("repository")
+        settings["cacert"] = settings.pop("cert")
         return cls(**settings)
 
     def _handle_package_signing(
-        self,
-        sign: bool,
-        sign_with: Optional[str],
-        identity: Optional[str]
+        self, sign: bool, sign_with: str, identity: Optional[str]
     ) -> None:
         if not sign and identity:
             raise exceptions.InvalidSigningConfiguration(
@@ -278,50 +289,39 @@ class Settings:
         self.identity = identity
 
     def _handle_repository_options(
-        self,
-        repository_name: str,
-        repository_url: Optional[str]
+        self, repository_name: str, repository_url: Optional[str]
     ) -> None:
         self.repository_config = utils.get_repository_from_config(
             self.config_file,
             repository_name,
             repository_url,
         )
-        self.repository_config['repository'] = utils.normalize_repository_url(
-            cast(str, self.repository_config['repository']),
-        )
 
     def _handle_certificates(
-        self,
-        cacert: Optional[str],
-        client_cert: Optional[str]
+        self, cacert: Optional[str], client_cert: Optional[str]
     ) -> None:
         self.cacert = utils.get_cacert(cacert, self.repository_config)
-        self.client_cert = utils.get_clientcert(
-            client_cert,
-            self.repository_config,
-        )
+        self.client_cert = utils.get_clientcert(client_cert, self.repository_config)
 
     def check_repository_url(self) -> None:
         """Verify we are not using legacy PyPI.
 
-        :raises:
-            :class:`~twine.exceptions.UploadToDeprecatedPyPIDetected`
+        :raises twine.exceptions.UploadToDeprecatedPyPIDetected:
+            The configured repository URL is for legacy PyPI.
         """
-        repository_url = cast(str, self.repository_config['repository'])
+        repository_url = cast(str, self.repository_config["repository"])
 
-        if repository_url.startswith((repository.LEGACY_PYPI,
-                                      repository.LEGACY_TEST_PYPI)):
+        if repository_url.startswith(
+            (repository.LEGACY_PYPI, repository.LEGACY_TEST_PYPI)
+        ):
             raise exceptions.UploadToDeprecatedPyPIDetected.from_args(
-                repository_url,
-                utils.DEFAULT_REPOSITORY,
-                utils.TEST_REPOSITORY
+                repository_url, utils.DEFAULT_REPOSITORY, utils.TEST_REPOSITORY
             )
 
     def create_repository(self) -> repository.Repository:
         """Create a new repository for uploading."""
         repo = repository.Repository(
-            cast(str, self.repository_config['repository']),
+            cast(str, self.repository_config["repository"]),
             self.username,
             self.password,
             self.disable_progress_bar,
