@@ -19,7 +19,7 @@ import logging
 import os
 import os.path
 import unicodedata
-from typing import Any, Callable, DefaultDict, Dict, Optional, Sequence, Union
+from typing import Any, Callable, DefaultDict, Dict, Optional, Sequence, Union, cast
 from urllib.parse import urlparse
 from urllib.parse import urlunparse
 
@@ -133,7 +133,7 @@ def get_repository_from_config(
         }
 
     try:
-        return get_config(config_file)[repository]
+        config = get_config(config_file)[repository]
     except OSError as exc:
         raise exceptions.InvalidConfiguration(str(exc))
     except KeyError:
@@ -142,6 +142,9 @@ def get_repository_from_config(
             f"More info: https://packaging.python.org/specifications/pypirc/ "
         )
 
+    config["repository"] = normalize_repository_url(cast(str, config["repository"]))
+    return config
+
 
 _HOSTNAMES = {
     "pypi.python.org",
@@ -255,9 +258,9 @@ def get_userpass_value(
             warning = f"Your {key} contains control characters"
 
         if warning:
-            logger.warning(f"  {warning}. Did you enter it correctly?")
+            logger.warning(f"{warning}. Did you enter it correctly?")
             logger.warning(
-                "  See https://twine.readthedocs.io/#entering-credentials "
+                "See https://twine.readthedocs.io/#entering-credentials "
                 "for more information."
             )
 
